# Security Policy

## Supported Versions

| Version | Supported |
|---------|-----------|
| 0.1.x   | Yes       |

## Reporting a Vulnerability

If you find a security vulnerability in inspect-mlflow, please report it privately:

1. **Do not** open a public GitHub issue
2. Email debusinha2009@gmail.com with details
3. Include steps to reproduce if possible

You should receive a response within 48 hours. Security fixes are prioritized over feature work.
